@@ -718,7 +718,10 @@ pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
+pref("network.IDN.whitelist.lu", true);
 pref("network.IDN.whitelist.no", true);
+pref("network.IDN.whitelist.nu", true);
+pref("network.IDN.whitelist.nz", true);
 pref("network.IDN.whitelist.pl", true);
 pref("network.IDN.whitelist.pr", true);
 pref("network.IDN.whitelist.se", true);
@@ -728,12 +731,21 @@ pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
-// non-ccTLDs
+// IDN ccTLDs
+// sa, Saudi Arabia, .<al-Saudiah>
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// jo, Jordan, .<Al-Ordon>
+pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+
+// gTLDs
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
 pref("network.IDN.whitelist.museum", true);
 pref("network.IDN.whitelist.org", true);
+pref("network.IDN.whitelist.tel", true);
 
 // NOTE: Before these can be removed, one of bug 414812's tests must be updated
 //       or it will likely fail!  Please CC jwalden+bmo on the bug associated
@@ -813,7 +825,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 835 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 847 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -841,9 +853,7 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 864 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 871 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -874,6 +884,9 @@ pref("network.proxy.autoconfig_url", "");
 pref("network.proxy.autoconfig_retry_interval_min", 5);    // 5 seconds
 pref("network.proxy.autoconfig_retry_interval_max", 300);  // 5 minutes
 
+pref("network.buffer.cache.count", 24);
+pref("network.buffer.cache.size",  4096);
+
 pref("converter.html2txt.structs",          true); // Output structured phrases (strong, em, code, sub, sup, b, i, u)
 pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention
 
@@ -1194,6 +1207,12 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
+// How long a plugin is allowed to process a synchronous IPC message
+// before we consider it "hung".
+//
+//  NB: chosen to match dom.max_script_run_time by default
+pref("dom.ipc.plugins.timeoutSecs", 10);
+
 pref("svg.enabled", true);
 pref("svg.smil.enabled", false);
 
@@ -1229,15 +1248,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1654 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1667 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2078 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2091 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2281 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2294 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2377 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2390 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2380 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2393 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1507,15 +1526,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2652 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2665 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2720 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2733 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2746 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2759 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2766 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2779 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2774 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2787 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1552,9 +1571,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2816 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2829 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2821 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2834 "/builds/slave/mozilla-1.9.2-linux-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
